==> Zephyrus-2.19.8.11281.tar.gz: Zephyrus-2.19.8.11281/Zephyrus/facebook/migrations/0007_auto_20180513_1051.py <==
# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('cms', '0016_auto_20160608_1535'),
        ('facebook', '0006_auto_20170917_0921'),
    ]

    operations = [
        migrations.CreateModel(
            name='ShareLike',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(parent_link=True, related_name='facebook_sharelike', auto_created=True, primary_key=True, serialize=False, to='cms.CMSPlugin')),
                ('layout', models.CharField(default=b'standard', max_length=15, choices=[(b'standard', b'Standard'), (b'button_count', b'Button Count'), (b'button', b'Button'), (b'box_count', b'Box Count')])),
                ('action', models.CharField(default=b'like', max_length=10, choices=[(b'like', b'Like'), (b'recommend', b'Recommend')])),
                ('size', models.CharField(default=b'small', max_length=5, choices=[(b'small', b'Small'), (b'large', b'Large')])),
                ('showFaces', models.BooleanField()),
                ('share', models.BooleanField()),
                ('appId', models.CharField(max_length=20)),
            ],
            options={
                'abstract': False,
            },
            bases=('cms.cmsplugin',),
        ),
        migrations.AlterField(
            model_name='facebookfan',
            name='renderTemplate',
            field=models.CharField(default=b'facebook/FacebookFanPlugin.html', max_length=150, verbose_name='Fan Template', blank=True, choices=[(b'facebook/FacebookFanPlugin.html', 'Default')]),
        ),
        migrations.AlterField(
            model_name='facebookphoto',
            name='renderTemplate',
            field=models.CharField(default=b'facebook/FacebookPhotoPlugin.html', max_length=150, verbose_name='Photo Template', blank=True, choices=[(b'facebook/FacebookPhotoPlugin.html', 'Default')]),
        ),
    ]

==> Zephyrus-3.7.25.12486.tar.gz: Zephyrus-3.7.25.12486/Zephyrus/facebook/migrations/0007_auto_20180513_1051.py <==
# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('cms', '0016_auto_20160608_1535'),
        ('facebook', '0006_auto_20170917_0921'),
    ]

    operations = [
        migrations.CreateModel(
            name='ShareLike',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(parent_link=True, related_name='facebook_sharelike', auto_created=True, primary_key=True, serialize=False, to='cms.CMSPlugin', on_delete=models.CASCADE)),
                ('layout', models.CharField(default=b'standard', max_length=15, choices=[(b'standard', b'Standard'), (b'button_count', b'Button Count'), (b'button', b'Button'), (b'box_count', b'Box Count')])),
                ('action', models.CharField(default=b'like', max_length=10, choices=[(b'like', b'Like'), (b'recommend', b'Recommend')])),
                ('size', models.CharField(default=b'small', max_length=5, choices=[(b'small', b'Small'), (b'large', b'Large')])),
                ('showFaces', models.BooleanField()),
                ('share', models.BooleanField()),
                ('appId', models.CharField(max_length=20)),
            ],
            options={
                'abstract': False,
            },
            bases=('cms.cmsplugin',),
        ),
        migrations.AlterField(
            model_name='facebookfan',
            name='renderTemplate',
            field=models.CharField(default=b'facebook/FacebookFanPlugin.html', max_length=150, verbose_name='Fan Template', blank=True, choices=[(b'facebook/FacebookFanPlugin.html', 'Default')]),
        ),
        migrations.AlterField(
            model_name='facebookphoto',
            name='renderTemplate',
            field=models.CharField(default=b'facebook/FacebookPhotoPlugin.html', max_length=150, verbose_name='Photo Template', blank=True, choices=[(b'facebook/FacebookPhotoPlugin.html', 'Default')]),
        ),
    ]
